@@ -139,6 +139,8 @@ def parse_params(params):
             params['gpus'] = [int(c) for c in params['gpus'].split(',')]
     if 'log_refresh_rate' in keys:
         params['log_refresh_rate'] = None if params['log_refresh_rate'] < 0 else int(params['log_refresh_rate'])
+    if 'train_val_test_split' in keys:
+        params['train_val_test_split'] = [float(item) for item in params['train_val_test_split'].split(',')]
 
     return params
 
